@@ -167,6 +167,7 @@ func runMain(cmd *cobra.Command, runCtx *config.RunContext) error {
 		ShowSkipped:       runCtx.Config.ShowSkipped,
 		NoColor:           runCtx.Config.NoColor,
 		Fields:            runCtx.Config.Fields,
+		CurrencyFormat:    runCtx.Config.CurrencyFormat,
 	})
 	if err != nil {
 		return err
@@ -481,6 +482,8 @@ func (r *parallelRunner) runProjectConfig(ctx *config.ProjectContext) (*projectO
 		return nil, err
 	}
 
+	r.buildResources(projects)
+
 	spinnerOpts := ui.SpinnerOptions{
 		EnableLogging: r.runCtx.Config.IsLogging(),
 		NoColor:       r.runCtx.Config.NoColor,
@@ -516,7 +519,6 @@ func (r *parallelRunner) runProjectConfig(ctx *config.ProjectContext) (*projectO
 
 			return nil, err
 		}
-
 		schema.CalculateCosts(project)
 
 		project.CalculateDiff()
@@ -530,6 +532,9 @@ func (r *parallelRunner) runProjectConfig(ctx *config.ProjectContext) (*projectO
 	wg.Wait()
 
 	spinner.Success()
+
+	r.populateActualCosts(projects)
+
 	out.projects = projects
 
 	if !r.runCtx.Config.IsLogging() && !r.runCtx.Config.SkipErrLine {
@@ -539,6 +544,92 @@ func (r *parallelRunner) runProjectConfig(ctx *config.ProjectContext) (*projectO
 	return out, nil
 }
 
+func (r *parallelRunner) buildResources(projects []*schema.Project) {
+	var projectPtrToUsageMap map[*schema.Project]map[string]*schema.UsageData
+	if r.runCtx.Config.UsageAPIEndpoint != "" {
+		projectPtrToUsageMap = r.fetchProjectUsage(projects)
+	}
+
+	for _, project := range projects {
+		usageMap := projectPtrToUsageMap[project]
+
+		for _, partial := range project.PartialResources {
+			u := usageMap[partial.ResourceData.Address]
+			project.Resources = append(project.Resources, schema.BuildResource(partial, u))
+		}
+
+		for _, partial := range project.PartialPastResources {
+			u := usageMap[partial.ResourceData.Address]
+			project.PastResources = append(project.PastResources, schema.BuildResource(partial, u))
+		}
+	}
+}
+
+func (r *parallelRunner) fetchProjectUsage(projects []*schema.Project) map[*schema.Project]map[string]*schema.UsageData {
+	coreResourceCount := 0
+	for _, project := range projects {
+		for _, partial := range project.PartialResources {
+			if partial.CoreResource != nil {
+				coreResourceCount++
+			}
+		}
+	}
+
+	if coreResourceCount == 0 {
+		return nil
+	}
+
+	resourceStr := fmt.Sprintf("%d resource", coreResourceCount)
+	if coreResourceCount > 1 {
+		resourceStr += "s"
+	}
+
+	spinnerOpts := ui.SpinnerOptions{
+		EnableLogging: r.runCtx.Config.IsLogging(),
+		NoColor:       r.runCtx.Config.NoColor,
+		Indent:        "  ",
+	}
+	spinner := ui.NewSpinner(fmt.Sprintf("Retrieving usage estimates for %s from Infracost Cloud", resourceStr), spinnerOpts)
+	defer spinner.Fail()
+
+	projectPtrToUsageMap := make(map[*schema.Project]map[string]*schema.UsageData, len(projects))
+
+	for _, project := range projects {
+		usageMap, err := prices.FetchUsageData(r.runCtx, project)
+		if err != nil {
+			logging.Logger.WithError(err).Debugf("failed to retrieve usage data for project %s", project.Name)
+			return nil
+		}
+
+		projectPtrToUsageMap[project] = usageMap
+	}
+
+	spinner.Success()
+
+	return projectPtrToUsageMap
+}
+
+func (r *parallelRunner) populateActualCosts(projects []*schema.Project) {
+	if r.runCtx.Config.UsageAPIEndpoint != "" {
+		spinnerOpts := ui.SpinnerOptions{
+			EnableLogging: r.runCtx.Config.IsLogging(),
+			NoColor:       r.runCtx.Config.NoColor,
+			Indent:        "  ",
+		}
+		spinner := ui.NewSpinner("Retrieving actual costs from Infracost Cloud", spinnerOpts)
+		defer spinner.Fail()
+
+		for _, project := range projects {
+			if err := prices.PopulateActualCosts(r.runCtx, project); err != nil {
+				logging.Logger.WithError(err).Debugf("failed to retrieve actual costs for project %s", project.Name)
+				return
+			}
+		}
+
+		spinner.Success()
+	}
+}
+
 func (r *parallelRunner) runHCLProvider(wg *sync.WaitGroup, ctx *config.ProjectContext, usageFile *usage.UsageFile, out *projectOutput) {
 	defer func() {
 		err := recover()
@@ -576,6 +667,11 @@ func (r *parallelRunner) runHCLProvider(wg *sync.WaitGroup, ctx *config.ProjectC
 			log.Debugf("Error populating prices for HCL project: %s", err)
 			return
 		}
+		err = prices.PopulateActualCosts(r.runCtx, project)
+		if err != nil {
+			log.Debugf("Error populating usages for HCL project: %s", err)
+			return
+		}
 
 		schema.CalculateCosts(project)
 		project.CalculateDiff()
@@ -612,6 +708,8 @@ func (r *parallelRunner) generateUsageFile(ctx *config.ProjectContext, provider
 		return errors.Wrap(err, "Error loading resources")
 	}
 
+	r.buildResources(providerProjects)
+
 	spinnerOpts := ui.SpinnerOptions{
 		EnableLogging: r.runCtx.Config.IsLogging(),
 		NoColor:       r.runCtx.Config.NoColor,
