@@ -45,7 +45,7 @@ func (p *TemplateProvider) LoadResources(usage map[string]*schema.UsageData) ([]
 	p.AddMetadata(metadata)
 	name := p.ctx.ProjectConfig.Name
 	if name == "" {
-		name = metadata.GenerateProjectName(p.ctx.RunContext.VCSMetadata.Remote.URL, p.ctx.RunContext.IsCloudEnabled())
+		name = metadata.GenerateProjectName(p.ctx.RunContext.VCSMetadata.Remote, p.ctx.RunContext.IsCloudEnabled())
 	}
 
 	project := schema.NewProject(name, metadata)
