@@ -11,6 +11,7 @@ import (
 	log "github.com/sirupsen/logrus"
 	"github.com/tidwall/gjson"
 
+	address_parser "github.com/hashicorp/go-terraform-address"
 	"github.com/infracost/infracost/internal/config"
 	"github.com/infracost/infracost/internal/providers/terraform/aws"
 	"github.com/infracost/infracost/internal/providers/terraform/azure"
@@ -34,7 +35,7 @@ func NewParser(ctx *config.ProjectContext, includePastResources bool) *Parser {
 	}
 }
 
-func (p *Parser) createResource(d *schema.ResourceData, u *schema.UsageData) *schema.Resource {
+func (p *Parser) createPartialResource(d *schema.ResourceData, u *schema.UsageData) *schema.PartialResource {
 	registryMap := GetResourceRegistryMap()
 
 	for cKey, cValue := range getSpecialContext(d) {
@@ -43,42 +44,50 @@ func (p *Parser) createResource(d *schema.ResourceData, u *schema.UsageData) *sc
 
 	if registryItem, ok := (*registryMap)[d.Type]; ok {
 		if registryItem.NoPrice {
-			return &schema.Resource{
-				Name:         d.Address,
-				ResourceType: d.Type,
-				Tags:         d.Tags,
-				IsSkipped:    true,
-				NoPrice:      true,
-				SkipMessage:  "Free resource.",
-				Metadata:     d.Metadata,
+			return &schema.PartialResource{
+				ResourceData: d,
+				Resource: &schema.Resource{
+					Name:        d.Address,
+					IsSkipped:   true,
+					NoPrice:     true,
+					SkipMessage: "Free resource.",
+				},
 			}
 		}
 
-		res := registryItem.RFunc(d, u)
-		if res != nil {
-			res.ResourceType = d.Type
-			res.Tags = d.Tags
-			res.Metadata = d.Metadata
+		// Use the CoreRFunc to generate a CoreResource if possible.  This is
+		// the new/preferred way to create provider-agnostic resources that
+		// support advanced features such as Infracost Cloud usage estimates
+		// and actual costs.
+		if registryItem.CoreRFunc != nil {
+			coreRes := registryItem.CoreRFunc(d)
+			if coreRes != nil {
+				return &schema.PartialResource{ResourceData: d, CoreResource: coreRes}
+			}
+		} else {
+			res := registryItem.RFunc(d, u)
+			if res != nil {
+				if u != nil {
+					res.EstimationSummary = u.CalcEstimationSummary()
+				}
 
-			if u != nil {
-				res.EstimationSummary = u.CalcEstimationSummary()
+				return &schema.PartialResource{ResourceData: d, Resource: res}
 			}
-			return res
 		}
 	}
 
-	return &schema.Resource{
-		Name:         d.Address,
-		ResourceType: d.Type,
-		Tags:         d.Tags,
-		IsSkipped:    true,
-		SkipMessage:  "This resource is not currently supported",
-		Metadata:     d.Metadata,
+	return &schema.PartialResource{
+		ResourceData: d,
+		Resource: &schema.Resource{
+			Name:        d.Address,
+			IsSkipped:   true,
+			SkipMessage: "This resource is not currently supported",
+		},
 	}
 }
 
-func (p *Parser) parseJSONResources(parsePrior bool, baseResources []*schema.Resource, usage map[string]*schema.UsageData, parsed, providerConf, conf, vars gjson.Result) []*schema.Resource {
-	var resources []*schema.Resource
+func (p *Parser) parseJSONResources(parsePrior bool, baseResources []*schema.PartialResource, usage map[string]*schema.UsageData, parsed, providerConf, conf, vars gjson.Result) []*schema.PartialResource {
+	var resources []*schema.PartialResource
 	resources = append(resources, baseResources...)
 	var vals gjson.Result
 
@@ -102,7 +111,7 @@ func (p *Parser) parseJSONResources(parsePrior bool, baseResources []*schema.Res
 	p.populateUsageData(resData, usage)
 
 	for _, d := range resData {
-		if r := p.createResource(d, d.UsageData); r != nil {
+		if r := p.createPartialResource(d, d.UsageData); r != nil {
 			resources = append(resources, r)
 		}
 	}
@@ -114,8 +123,21 @@ func (p *Parser) parseJSONResources(parsePrior bool, baseResources []*schema.Res
 // in case it is needed when processing a reference attribute
 func (p *Parser) populateUsageData(resData map[string]*schema.ResourceData, usage map[string]*schema.UsageData) {
 	for _, d := range resData {
+		// Look and default to resource_type level data
+		parsed_address, err := address_parser.NewAddress(d.Address)
+		if err == nil {
+			val, ok := usage[parsed_address.ResourceSpec.Type]
+			if ok {
+				d.UsageData = val
+			}
+		}
+
 		if ud := usage[d.Address]; ud != nil {
-			d.UsageData = ud
+			if d.UsageData != nil {
+				schema.MergeAttributes(d.UsageData, ud)
+			} else {
+				d.UsageData = ud
+			}
 		} else if strings.HasSuffix(d.Address, "]") {
 			lastIndexOfOpenBracket := strings.LastIndex(d.Address, "[")
 
@@ -126,7 +148,7 @@ func (p *Parser) populateUsageData(resData map[string]*schema.ResourceData, usag
 	}
 }
 
-func (p *Parser) parseJSON(j []byte, usage map[string]*schema.UsageData) ([]*schema.Resource, []*schema.Resource, error) {
+func (p *Parser) parseJSON(j []byte, usage map[string]*schema.UsageData) ([]*schema.PartialResource, []*schema.PartialResource, error) {
 	baseResources := p.loadUsageFileResources(usage)
 
 	j, _ = StripSetupTerraformWrapper(j)
@@ -168,8 +190,8 @@ func StripSetupTerraformWrapper(b []byte) ([]byte, bool) {
 	return stripped, len(stripped) != len(b)
 }
 
-func (p *Parser) loadUsageFileResources(u map[string]*schema.UsageData) []*schema.Resource {
-	resources := make([]*schema.Resource, 0)
+func (p *Parser) loadUsageFileResources(u map[string]*schema.UsageData) []*schema.PartialResource {
+	resources := make([]*schema.PartialResource, 0)
 
 	for k, v := range u {
 		for _, t := range GetUsageOnlyResources() {
@@ -178,7 +200,7 @@ func (p *Parser) loadUsageFileResources(u map[string]*schema.UsageData) []*schem
 				// set the usage data as a field on the resource data in case it is needed when
 				// processing reference attributes.
 				d.UsageData = v
-				if r := p.createResource(d, v); r != nil {
+				if r := p.createPartialResource(d, v); r != nil {
 					resources = append(resources, r)
 				}
 			}
@@ -193,10 +215,10 @@ func (p *Parser) loadUsageFileResources(u map[string]*schema.UsageData) []*schem
 // is run with `-target` then all resources still appear in prior_state but not
 // in planned_values. This makes sure we remove any non-target resources from
 // the past resources so that we only show resources matching the target.
-func stripNonTargetResources(pastResources []*schema.Resource, resources []*schema.Resource, resourceChanges []gjson.Result) []*schema.Resource {
+func stripNonTargetResources(pastResources []*schema.PartialResource, resources []*schema.PartialResource, resourceChanges []gjson.Result) []*schema.PartialResource {
 	resourceAddrMap := make(map[string]bool, len(resources))
 	for _, resource := range resources {
-		resourceAddrMap[resource.Name] = true
+		resourceAddrMap[resource.ResourceData.Address] = true
 	}
 
 	diffAddrMap := make(map[string]bool, len(resourceChanges))
@@ -204,10 +226,10 @@ func stripNonTargetResources(pastResources []*schema.Resource, resources []*sche
 		diffAddrMap[change.Get("address").String()] = true
 	}
 
-	var filteredResources []*schema.Resource
+	var filteredResources []*schema.PartialResource
 	for _, resource := range pastResources {
-		_, rOk := resourceAddrMap[resource.Name]
-		_, dOk := diffAddrMap[resource.Name]
+		_, rOk := resourceAddrMap[resource.ResourceData.Address]
+		_, dOk := diffAddrMap[resource.ResourceData.Address]
 		if dOk || rOk {
 			filteredResources = append(filteredResources, resource)
 		}
