@@ -151,7 +151,7 @@ func (p *TerragruntHCLProvider) LoadResources(usage map[string]*schema.UsageData
 			p.AddMetadata(project.Metadata)
 			name := p.ctx.ProjectConfig.Name
 			if name == "" {
-				name = project.Metadata.GenerateProjectName(p.ctx.RunContext.VCSMetadata.Remote.URL, p.ctx.RunContext.IsCloudEnabled())
+				name = project.Metadata.GenerateProjectName(p.ctx.RunContext.VCSMetadata.Remote, p.ctx.RunContext.IsCloudEnabled())
 			}
 
 			project.Name = name
@@ -337,7 +337,6 @@ func (p *TerragruntHCLProvider) runTerragrunt(opts *tgoptions.TerragruntOptions)
 		config.NewProjectContext(p.ctx.RunContext, &pconfig, fields),
 		&HCLProviderConfig{CacheParsingModules: true},
 		hcl.OptionWithSpinner(p.ctx.RunContext.NewSpinner),
-		hcl.OptionWithWarningFunc(p.ctx.RunContext.NewWarningWriter()),
 		hcl.OptionWithRawCtyInput(inputs),
 	)
 	if err != nil {
