@@ -100,7 +100,7 @@ func (r *PostgreSQLFlexibleServer) storageCostComponent() *schema.CostComponent
 			Service:       strPtr("Azure Database for PostgreSQL"),
 			ProductFamily: strPtr("Databases"),
 			AttributeFilters: []*schema.AttributeFilter{
-				{Key: "productName", Value: strPtr("Azure Database for PostgreSQL Flexible Server Storage")},
+				{Key: "productName", Value: strPtr("Az DB for PostgreSQL Flexible Server Storage")},
 				{Key: "meterName", Value: strPtr("Storage Data Stored")},
 			},
 		},
